********
Overview
********
NOC is an Operation Support System (OSS) for the Telecommunication company, Service provider and Enterprise Network's Operation Centers (NOC). 

Areas covered by NOC:

* Fault Management
* Service Activation/Provisioning
* Multi-VRF Address space management
* Virtual Circuits management
* Configuration Management
* DNS provisioning
* Peering management, RPSL and BGP filters generator, integrated looking glass
* Reporting

NOC is Open Source Software distributed under the terms of BSD-like :ref:`LICENSE`.
